% *************************************************************
% GABSOBHIN - Genetic Algorithms Based Synthesis & Optimization
% of Batch Heat Integration Networks - Copyright LENI-EPFL 2000
% Development Pierre KRUMMENACHER & Blaise RENAUD for LENI-EPFL 
% *************************************************************
% I_Return_OF_Value.m /  01.03.01 - .........
% *************************************************************
% Write return parameters to GAlib (mainly OF and related side
% values, as well as vector of T representing the individual
% for distance measurement)
% *************************************************************
% INPUT:
%		:	
%
% OUTPUT:
%		:	
% *************************************************************
% to do:
%
% INTERNAL VARIABLES
%		:	
% *************************************************************

if PSOS.help_print == 1
   help I_Return_OF_Value
end

if PSOS.step_print == 1
   disp('*** I_Return_OF_Value ***');
end

%	select the OF to return depending on PSOS.OFType:
%	note that RD.ngen used below is calculated in I_Results_Update !!!

switch PSOS.OFType
case 1	%	minimization of TBCs (possibly in several phases)
   
   if PSOS.OMode == 2	%	i.e. three-step optimization: first -HR (HR to be maximized),then a variable blend of
      %	-HR with TBCs, and finally TBCs (to be minimized)
   	if RD.ngen <= ceil(PSOS.PMOF_HR * PSOS.NGen)	%	first step: maximization of HR
         RD.alpha = 0;
         
         OF = -RD.HR + PSOS.MF_HR_max_TBCs_max * (RD.HR_max + RD.TBCs_max_approx);
         %	the above calculation of (modified) OF is the general blended OF expression below particularized
         %	to the case RD.alpha = 0. the addition of PSOS.MF_HR_max_TBCs_max * (RD.HR_max + RD.TBCs_max_approx) 
      	%	is required to avoid (temporary) OF values smaller than TBCs_max_approx, otherwise individuals judged
      	%	as good and kept in population during the HR optimization phase shall potentially not be replaced
      	%	afterwards (no TBCs better, i.e. smaller, than the OF found during early HR maximization phase)
      	Side_Val = RD.TBCs;
   	
      else
         if RD.ngen <= (ceil(PSOS.PMOF_HR * PSOS.NGen) + ceil(PSOS.PMOF_HR_TBCs * PSOS.NGen))	%	second step: maximization of a 
            %	blend of HR & TBCs
            %	calculate alpha:
            RD.alpha = ceil((RD.ngen - ceil(PSOS.PMOF_HR * PSOS.NGen))/(RD.N_Blend_delta_gen))/(RD.N_Blend_OF + 1);
            
         	OF = RD.alpha * RD.TBCs - (1 - RD.alpha) * RD.HR + (1 - RD.alpha) * PSOS.MF_HR_max_TBCs_max * (RD.HR_max + RD.TBCs_max_approx);
      		Side_Val = RD.TBCs;
            
         else	%	third step: minimization of TBCs
            
            RD.alpha = 1;
            OF = RD.TBCs;
            Side_Val = RD.HR;
            
         end
      
   	end
   
	else	%	i.e. PSOS.OMode == 1
   	OF = RD.TBCs;
   	Side_Val = RD.HR;
   
	end

case 2	%	maximization of HR
   
   OF = -RD.HR;	%	sign is corrected in RAve for display
   Side_Val = RD.TBCs;
   
otherwise
   %	not a case to be found
end	%	switch PSOS.OFType



%	definition of returned values to be associated to the genome: see I_Exec_DLL

yret1 = ones(1,15);


yret1(1) = RD.TBCs;
yret1(2) = RD.HR;
yret1(3) = RD.HU_oper_Costs + RD.CU_oper_Costs;
yret1(4) = OF;
yret1(5) = 0;	%	to be used to store OF_mean (managed by C++ optimize/GAmain side)
yret1(6) = Side_Val;
yret1(7) = RD.HEX_B_Costs;
yret1(8) = RD.HSU_B_Costs;
yret1(9) = RD.TC_B_Costs;
yret1(10) = RD.HU_capi_B_Costs;
yret1(11) = RD.CU_capi_B_Costs;
yret1(12) = RD.HU_oper_Costs;
yret1(13) = RD.CU_oper_Costs;
yret1(14) = RD.HU_tot;
yret1(15) = RD.CU_tot;

%	
if PSOS.M_trace_print > 0
	disparray(yret1,15,4,'yret1');
end;

yret2 = DD.D_var;
yret3 = DD.NDV;

% *************************************************************